import requests

class shop():
    def shop_info(shop_key):
        url = "https://easydonate.ru/api/v3/shop"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class product():
    def get_products(shop_key):
        url = "https://easydonate.ru/api/v3/shop/products"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

    def get_product(shop_key, id):
        url = f"https://easydonate.ru/api/v3/shop/product/{id}"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class server():
    def get_servers(shop_key):
        url = "https://easydonate.ru/api/v3/shop/servers"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

    def get_server(shop_key, id):
        url = f"https://easydonate.ru/api/v3/shop/server/{id}"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class vouchers():
    def mass_sales(shop_key):
        url = "https://easydonate.ru/api/v3/shop/massSales"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

    def coupons(shop_key, where_active):
        url = f"https://easydonate.ru/api/v3/shop/coupons"
        headers={"Shop-Key": shop_key}
        params = {
            'where_active': where_active
        }
        if where_active:
            response = requests.get(url=url, headers=headers, params=params)
        else:
            response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class paymets():
    def payments(shop_key):
        url = "https://easydonate.ru/api/v3/shop/payments"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
        
    def payment(shop_key, id):
        url = f"https://easydonate.ru/api/v3/shop/payment/{id}"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация!")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

    def create_payment(shop_key, customer, server_id, products, email, coupon, success_url):
        url = "https://easydonate.ru/api/v3/shop/payment/create"
        headers={"Shop-Key": shop_key}
        params = {
            'customer': customer,
            'server_id': server_id,
            'products': products
        }
        if email:
            params['email'] = email
        if coupon:
            params['coupon'] = coupon
        if success_url:
            params['success_url'] = success_url
        response = requests.get(url=url, headers=headers, params=params)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Не найдена информация или неправильно введены параметры.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})


import requests

class additional_payment():
    def additional_payment_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/EasyDonate.Surcharge/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def additional_payment_user(shop_key, username):
        url = "https://easydonate.ru/api/v3/plugin/EasyDonate.Surcharge/getDiscounts"
        headers={"Shop-Key": shop_key}
        params={'username': username}
        response = requests.get(url=url, headers=headers, params=params)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def additional_payment_id(shop_key, username, product_id):
        url = "https://easydonate.ru/api/v3/plugin/EasyDonate.Surcharge/getDiscounts"
        headers={"Shop-Key": shop_key}
        params={'username': username, 'product_id': product_id}
        response = requests.get(url=url, headers=headers, params=params)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class last_payments():
    def last_payments_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/EasyDonate.LastPayments/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def last_payments_get(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/EasyDonate.LastPayments/getPayments"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class custom_message():
    def custom_message_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/EasyDonate.CustomMessages/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class discord_widget():
    def discord_widget_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Discord.Widget/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def discord_widget_get(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Discord.Widget/getEmbed"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class vk():
    def vk_widget_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Vkontakte.Widget/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def vk_widget_get(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Vkontakte.Widget/getEmbed"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def vk_news_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Vkontakte.News/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def vk_news_get(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Vkontakte.News/getNews"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def vk_messages_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Vkontakte.MessagesWidget/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def vk_messages_widget(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Vkontakte.MessagesWidget/getEmbed"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})

class yandex_metrika():
    def yandex_metrika_settings(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Yandex.Metrika/getSettings"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})
    def yandex_metrika_widget(shop_key):
        url = "https://easydonate.ru/api/v3/plugin/Yandex.Metrika/getEmbed"
        headers={"Shop-Key": shop_key}
        response = requests.get(url=url, headers=headers)
        if response.status_code == 200:
            data = response.json()
            if data["success"] == "true":
                return data
            else:
                print("Возможно плагин отключен.")
        else:
            print({'error': f"Ошибка: {response.status_code}"})